@@ -12,17 +12,35 @@ build_home_md <- function(pkg) {
   handled <- c("README.md", "LICENSE.md", "LICENCE.md", "NEWS.md", "cran-comments.md")
   mds <- mds[!path_file(mds) %in% handled]
 
+  # Do not build 404 page if in-dev
+  if (pkg$development$in_dev) {
+    mds <- mds[fs::path_file(mds) != "404.md"]
+  }
+
   lapply(mds, render_md, pkg = pkg)
   invisible()
 }
 
 render_md <- function(pkg, filename) {
-  body <- markdown(path = filename, strip_header = TRUE)
+  body <- markdown_body(filename, strip_header = TRUE, pkg = pkg)
+  path <- path_ext_set(basename(filename), "html")
 
   cat_line("Reading ", src_path(path_rel(filename, pkg$src_path)))
 
   render_page(pkg, "title-body",
-    data = list(pagetitle = attr(body, "title"), body = body),
-    path = path_ext_set(basename(filename), "html")
+    data = list(
+      pagetitle = attr(body, "title"),
+      body = body,
+      filename = filename,
+      source = repo_source(pkg, fs::path_rel(filename, pkg$src_path))
+    ),
+    path = path
   )
+
+  if (path == "404.html") {
+    update_html(path(pkg$dst_path, path), tweak_link_absolute, pkg = pkg)
+  }
+  check_missing_images(pkg, filename, path)
+
+  invisible()
 }
